#
# spec file for package maven-filtering
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-filtering
Version:        3.2.0
Release:        150200.3.4.3
Summary:        Shared component providing resource filtering
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/shared/%{name}/index.html
Source0:        https://repo1.maven.org/maven2/org/apache/maven/shared/%{name}/%{version}/%{name}-%{version}-source-release.zip
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  apache-commons-cli
BuildRequires:  apache-commons-io
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  google-guice
BuildRequires:  guava
BuildRequires:  javapackages-local
BuildRequires:  jdom2
BuildRequires:  jsr-305
BuildRequires:  maven-lib
BuildRequires:  maven-shared-utils
BuildRequires:  objectweb-asm
BuildRequires:  plexus-build-api
BuildRequires:  plexus-classworlds
BuildRequires:  plexus-cli
BuildRequires:  plexus-containers-component-annotations
BuildRequires:  plexus-interpolation
BuildRequires:  plexus-metadata-generator
BuildRequires:  plexus-utils
BuildRequires:  qdox
BuildRequires:  sisu-inject
BuildRequires:  sisu-plexus
BuildRequires:  unzip
BuildRequires:  xmvn-install
BuildRequires:  xmvn-resolve
BuildRequires:  mvn(org.apache.maven.shared:maven-shared-components:pom:)
BuildArch:      noarch

%description
These Plexus components have been built from the filtering process/code in
Maven Resources Plugin. The goal is to provide a shared component for all
plugins that needs to filter resources.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml

%build
mkdir -p lib
build-jar-repository -s lib \
    maven/maven-core \
    maven/maven-model \
    maven/maven-settings \
    org.eclipse.sisu.plexus \
    plexus-containers/plexus-component-annotations \
    maven-shared-utils/maven-shared-utils \
    plexus/utils \
    plexus/interpolation \
    plexus/plexus-build-api \
    commons-io \
    jsr-305 \
    \
    atinject \
    commons-cli \
    guava/guava \
    guice/google-guice-no_aop \
    jdom2/jdom2 \
    objectweb-asm/asm \
    org.eclipse.sisu.inject \
    plexus-classworlds \
    plexus-metadata-generator \
    plexus/cli \
    qdox

# Tests use a package that is no longer present in plexus-build-api (v0.0.7)
%{ant} \
  jar javadoc

%{mvn_artifact} pom.xml target/%{name}-%{version}.jar

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Thu Apr 28 2022 fstrba@suse.com
- Upgrade to version 3.2.0
  * Bug
    + [MSHARED-417] - Infinite loop when loading self-referencing
    properties
    + [MSHARED-599] - Escaping the escape string produces incorrect
    output.
    + [MSHARED-829] - MavenResourcesExecution.copyOf() returns
    newinstance without properties set
  * New Feature
    + [MSHARED-934] - Allow using a different encoding when
    filtering properties files
  * Improvement
    + [MSHARED-646] - Removed prerequisites for none maven-plugin
    project
    + [MSHARED-664] - Add ico files to default non-filtered
    extensions
    + [MSHARED-830] - Require Java 7
    + [MSHARED-879] - make build Reproducible
    + [MSHARED-884] - Only overwrite filtered resources when
    contents differ
    + [MSHARED-946] - Update to maven-shared-utils 3.3.3
  * Dependency upgrade
    + [MSHARED-575] - Upgrade maven-shared-utils to 3.1.0
    + [MSHARED-600] - Upgrade of plexus-interpolation to 1.24.
    + [MSHARED-645] - Upgrade to maven-shared-utils 3.2.0
    + [MSHARED-667] - plexus-utils 3.0.24 to 3.1.0
    + [MSHARED-711] - Upgrade parent to 31
    + [MSHARED-712] - Upgrade maven-surefire/failsafe-plugin
    2.21.0 for JDK 10
    + [MSHARED-755] - Upgrade parent to version 32.
    + [MSHARED-756] - Upgrade plexus-interpolation to 1.25
    + [MSHARED-757] - Upgrade maven-shared-utils to 3.2.1
    + [MSHARED-758] - Upgrade JUnit to 4.12
    + [MSHARED-789] - Upgrade maven-shared-components parent
    to 33
    + [MSHARED-790] - Upgrade plexus-utils 3.1.1
    + [MSHARED-809] - Upgrade plexus-utils 3.2.0
  * needed by maven-resources-plugin 3.2.0
* Sun Mar 20 2022 fstrba@suse.com
- Build with source and target levels 8
* Tue May 11 2021 fstrba@suse.com
- Do not build against legacy guava20 any more
* Mon Mar 25 2019 fstrba@suse.com
- Initial packaging of maven-filtering 3.1.1
- Generate and customize the ant build.xml file
